/*
 * Copyright 2010-2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.chimesdkidentity.model;

import java.io.Serializable;

public class CreateAppInstanceAdminResult implements Serializable {
    /**
     * <p>
     * The ARN and name of the administrator, the ARN of the
     * <code>AppInstance</code>, and the created and last-updated timestamps.
     * All timestamps use epoch milliseconds.
     * </p>
     */
    private Identity appInstanceAdmin;

    /**
     * <p>
     * The ARN of the of the admin for the <code>AppInstance</code>.
     * </p>
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>5 - 1600<br/>
     * <b>Pattern:
     * </b>arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:
     * [a-z0-9-\.]{0,63}:[^/].{0,1023}<br/>
     */
    private String appInstanceArn;

    /**
     * <p>
     * The ARN and name of the administrator, the ARN of the
     * <code>AppInstance</code>, and the created and last-updated timestamps.
     * All timestamps use epoch milliseconds.
     * </p>
     *
     * @return <p>
     *         The ARN and name of the administrator, the ARN of the
     *         <code>AppInstance</code>, and the created and last-updated
     *         timestamps. All timestamps use epoch milliseconds.
     *         </p>
     */
    public Identity getAppInstanceAdmin() {
        return appInstanceAdmin;
    }

    /**
     * <p>
     * The ARN and name of the administrator, the ARN of the
     * <code>AppInstance</code>, and the created and last-updated timestamps.
     * All timestamps use epoch milliseconds.
     * </p>
     *
     * @param appInstanceAdmin <p>
     *            The ARN and name of the administrator, the ARN of the
     *            <code>AppInstance</code>, and the created and last-updated
     *            timestamps. All timestamps use epoch milliseconds.
     *            </p>
     */
    public void setAppInstanceAdmin(Identity appInstanceAdmin) {
        this.appInstanceAdmin = appInstanceAdmin;
    }

    /**
     * <p>
     * The ARN and name of the administrator, the ARN of the
     * <code>AppInstance</code>, and the created and last-updated timestamps.
     * All timestamps use epoch milliseconds.
     * </p>
     * <p>
     * Returns a reference to this object so that method calls can be chained
     * together.
     *
     * @param appInstanceAdmin <p>
     *            The ARN and name of the administrator, the ARN of the
     *            <code>AppInstance</code>, and the created and last-updated
     *            timestamps. All timestamps use epoch milliseconds.
     *            </p>
     * @return A reference to this updated object so that method calls can be
     *         chained together.
     */
    public CreateAppInstanceAdminResult withAppInstanceAdmin(Identity appInstanceAdmin) {
        this.appInstanceAdmin = appInstanceAdmin;
        return this;
    }

    /**
     * <p>
     * The ARN of the of the admin for the <code>AppInstance</code>.
     * </p>
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>5 - 1600<br/>
     * <b>Pattern:
     * </b>arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:
     * [a-z0-9-\.]{0,63}:[^/].{0,1023}<br/>
     *
     * @return <p>
     *         The ARN of the of the admin for the <code>AppInstance</code>.
     *         </p>
     */
    public String getAppInstanceArn() {
        return appInstanceArn;
    }

    /**
     * <p>
     * The ARN of the of the admin for the <code>AppInstance</code>.
     * </p>
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>5 - 1600<br/>
     * <b>Pattern:
     * </b>arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:
     * [a-z0-9-\.]{0,63}:[^/].{0,1023}<br/>
     *
     * @param appInstanceArn <p>
     *            The ARN of the of the admin for the <code>AppInstance</code>.
     *            </p>
     */
    public void setAppInstanceArn(String appInstanceArn) {
        this.appInstanceArn = appInstanceArn;
    }

    /**
     * <p>
     * The ARN of the of the admin for the <code>AppInstance</code>.
     * </p>
     * <p>
     * Returns a reference to this object so that method calls can be chained
     * together.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>5 - 1600<br/>
     * <b>Pattern:
     * </b>arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:
     * [a-z0-9-\.]{0,63}:[^/].{0,1023}<br/>
     *
     * @param appInstanceArn <p>
     *            The ARN of the of the admin for the <code>AppInstance</code>.
     *            </p>
     * @return A reference to this updated object so that method calls can be
     *         chained together.
     */
    public CreateAppInstanceAdminResult withAppInstanceArn(String appInstanceArn) {
        this.appInstanceArn = appInstanceArn;
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getAppInstanceAdmin() != null)
            sb.append("AppInstanceAdmin: " + getAppInstanceAdmin() + ",");
        if (getAppInstanceArn() != null)
            sb.append("AppInstanceArn: " + getAppInstanceArn());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode
                + ((getAppInstanceAdmin() == null) ? 0 : getAppInstanceAdmin().hashCode());
        hashCode = prime * hashCode
                + ((getAppInstanceArn() == null) ? 0 : getAppInstanceArn().hashCode());
        return hashCode;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof CreateAppInstanceAdminResult == false)
            return false;
        CreateAppInstanceAdminResult other = (CreateAppInstanceAdminResult) obj;

        if (other.getAppInstanceAdmin() == null ^ this.getAppInstanceAdmin() == null)
            return false;
        if (other.getAppInstanceAdmin() != null
                && other.getAppInstanceAdmin().equals(this.getAppInstanceAdmin()) == false)
            return false;
        if (other.getAppInstanceArn() == null ^ this.getAppInstanceArn() == null)
            return false;
        if (other.getAppInstanceArn() != null
                && other.getAppInstanceArn().equals(this.getAppInstanceArn()) == false)
            return false;
        return true;
    }
}
