/*
 * Copyright 2010-2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.connect.model;

import java.io.Serializable;

public class ListDefaultVocabulariesResult implements Serializable {
    /**
     * <p>
     * A list of default vocabularies.
     * </p>
     */
    private java.util.List<DefaultVocabulary> defaultVocabularyList;

    /**
     * <p>
     * If there are additional results, this is the token for the next set of
     * results.
     * </p>
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 131070<br/>
     * <b>Pattern: </b>.*\S.*<br/>
     */
    private String nextToken;

    /**
     * <p>
     * A list of default vocabularies.
     * </p>
     *
     * @return <p>
     *         A list of default vocabularies.
     *         </p>
     */
    public java.util.List<DefaultVocabulary> getDefaultVocabularyList() {
        return defaultVocabularyList;
    }

    /**
     * <p>
     * A list of default vocabularies.
     * </p>
     *
     * @param defaultVocabularyList <p>
     *            A list of default vocabularies.
     *            </p>
     */
    public void setDefaultVocabularyList(
            java.util.Collection<DefaultVocabulary> defaultVocabularyList) {
        if (defaultVocabularyList == null) {
            this.defaultVocabularyList = null;
            return;
        }

        this.defaultVocabularyList = new java.util.ArrayList<DefaultVocabulary>(
                defaultVocabularyList);
    }

    /**
     * <p>
     * A list of default vocabularies.
     * </p>
     * <p>
     * Returns a reference to this object so that method calls can be chained
     * together.
     *
     * @param defaultVocabularyList <p>
     *            A list of default vocabularies.
     *            </p>
     * @return A reference to this updated object so that method calls can be
     *         chained together.
     */
    public ListDefaultVocabulariesResult withDefaultVocabularyList(
            DefaultVocabulary... defaultVocabularyList) {
        if (getDefaultVocabularyList() == null) {
            this.defaultVocabularyList = new java.util.ArrayList<DefaultVocabulary>(
                    defaultVocabularyList.length);
        }
        for (DefaultVocabulary value : defaultVocabularyList) {
            this.defaultVocabularyList.add(value);
        }
        return this;
    }

    /**
     * <p>
     * A list of default vocabularies.
     * </p>
     * <p>
     * Returns a reference to this object so that method calls can be chained
     * together.
     *
     * @param defaultVocabularyList <p>
     *            A list of default vocabularies.
     *            </p>
     * @return A reference to this updated object so that method calls can be
     *         chained together.
     */
    public ListDefaultVocabulariesResult withDefaultVocabularyList(
            java.util.Collection<DefaultVocabulary> defaultVocabularyList) {
        setDefaultVocabularyList(defaultVocabularyList);
        return this;
    }

    /**
     * <p>
     * If there are additional results, this is the token for the next set of
     * results.
     * </p>
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 131070<br/>
     * <b>Pattern: </b>.*\S.*<br/>
     *
     * @return <p>
     *         If there are additional results, this is the token for the next
     *         set of results.
     *         </p>
     */
    public String getNextToken() {
        return nextToken;
    }

    /**
     * <p>
     * If there are additional results, this is the token for the next set of
     * results.
     * </p>
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 131070<br/>
     * <b>Pattern: </b>.*\S.*<br/>
     *
     * @param nextToken <p>
     *            If there are additional results, this is the token for the
     *            next set of results.
     *            </p>
     */
    public void setNextToken(String nextToken) {
        this.nextToken = nextToken;
    }

    /**
     * <p>
     * If there are additional results, this is the token for the next set of
     * results.
     * </p>
     * <p>
     * Returns a reference to this object so that method calls can be chained
     * together.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 131070<br/>
     * <b>Pattern: </b>.*\S.*<br/>
     *
     * @param nextToken <p>
     *            If there are additional results, this is the token for the
     *            next set of results.
     *            </p>
     * @return A reference to this updated object so that method calls can be
     *         chained together.
     */
    public ListDefaultVocabulariesResult withNextToken(String nextToken) {
        this.nextToken = nextToken;
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getDefaultVocabularyList() != null)
            sb.append("DefaultVocabularyList: " + getDefaultVocabularyList() + ",");
        if (getNextToken() != null)
            sb.append("NextToken: " + getNextToken());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime
                * hashCode
                + ((getDefaultVocabularyList() == null) ? 0 : getDefaultVocabularyList().hashCode());
        hashCode = prime * hashCode + ((getNextToken() == null) ? 0 : getNextToken().hashCode());
        return hashCode;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof ListDefaultVocabulariesResult == false)
            return false;
        ListDefaultVocabulariesResult other = (ListDefaultVocabulariesResult) obj;

        if (other.getDefaultVocabularyList() == null ^ this.getDefaultVocabularyList() == null)
            return false;
        if (other.getDefaultVocabularyList() != null
                && other.getDefaultVocabularyList().equals(this.getDefaultVocabularyList()) == false)
            return false;
        if (other.getNextToken() == null ^ this.getNextToken() == null)
            return false;
        if (other.getNextToken() != null
                && other.getNextToken().equals(this.getNextToken()) == false)
            return false;
        return true;
    }
}
