/*
 * Copyright 2010-2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.kinesisvideo.model.transform;

import com.amazonaws.services.kinesisvideo.model.*;
import com.amazonaws.util.DateUtils;
import com.amazonaws.util.json.AwsJsonWriter;

/**
 * JSON marshaller for POJO ImageGenerationDestinationConfig
 */
class ImageGenerationDestinationConfigJsonMarshaller {

    public void marshall(ImageGenerationDestinationConfig imageGenerationDestinationConfig,
            AwsJsonWriter jsonWriter) throws Exception {
        jsonWriter.beginObject();
        if (imageGenerationDestinationConfig.getUri() != null) {
            String uri = imageGenerationDestinationConfig.getUri();
            jsonWriter.name("Uri");
            jsonWriter.value(uri);
        }
        if (imageGenerationDestinationConfig.getDestinationRegion() != null) {
            String destinationRegion = imageGenerationDestinationConfig.getDestinationRegion();
            jsonWriter.name("DestinationRegion");
            jsonWriter.value(destinationRegion);
        }
        jsonWriter.endObject();
    }

    private static ImageGenerationDestinationConfigJsonMarshaller instance;

    public static ImageGenerationDestinationConfigJsonMarshaller getInstance() {
        if (instance == null)
            instance = new ImageGenerationDestinationConfigJsonMarshaller();
        return instance;
    }
}
