/*
 * Copyright 2010-2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.machinelearning.model.transform;

import com.amazonaws.services.machinelearning.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for POJO Prediction
 */
class PredictionJsonUnmarshaller implements Unmarshaller<Prediction, JsonUnmarshallerContext> {

    public Prediction unmarshall(JsonUnmarshallerContext context) throws Exception {
        AwsJsonReader reader = context.getReader();
        if (!reader.isContainer()) {
            reader.skipValue();
            return null;
        }
        Prediction prediction = new Prediction();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("predictedLabel")) {
                prediction.setPredictedLabel(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("predictedValue")) {
                prediction.setPredictedValue(FloatJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("predictedScores")) {
                prediction.setPredictedScores(new MapUnmarshaller<Float>(FloatJsonUnmarshaller
                        .getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("details")) {
                prediction.setDetails(new MapUnmarshaller<String>(StringJsonUnmarshaller
                        .getInstance()
                        )
                                .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();
        return prediction;
    }

    private static PredictionJsonUnmarshaller instance;

    public static PredictionJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new PredictionJsonUnmarshaller();
        return instance;
    }
}
